Standard Commutative Rings
==========================

Integers
--------

.. toctree::
   :maxdepth: 1

   sage/rings/integer_ring
   sage/rings/integer
   sage/rings/bernmm
   sage/rings/bernoulli_mod_p
   sage/rings/factorint
   sage/rings/factorint_flint
   sage/rings/factorint_pari
   sage/rings/fast_arith
   sage/rings/sum_of_squares
   sage/arith/functions
   sage/arith/power
   sage/arith/multi_modular
   sage/arith/misc

.. SEEALSO::

    - :mod:`sage.sets.integer_range`
    - :mod:`sage.sets.positive_integers`
    - :mod:`sage.sets.non_negative_integers`
    - :mod:`sage.sets.primes`

Rationals
---------

.. toctree::
   :maxdepth: 1

   sage/rings/rational_field
   sage/rings/rational

.. include:: ../footer.txt
